==> thunderbird_60.6.1.orig.tar.xz: thunderbird-60.6.1/tools/lint/eslint/eslint-plugin-mozilla/lib/configs/browser-test.js <==
// Parent config file for all browser-chrome files.
"use strict";

module.exports = {
  "env": {
    "browser": true,
    "mozilla/browser-window": true,
    "mozilla/simpletest": true
    // "node": true
  },

  // All globals made available in the test environment.
  "globals": {
    // `$` is defined in SimpleTest.js
    "$": false,
    "Assert": false,
    "BrowserTestUtils": false,
    "ContentTask": false,
    "ContentTaskUtils": false,
    "EventUtils": false,
    "PromiseDebugging": false,
    "SpecialPowers": false,
    "TestUtils": false,
    "XPCNativeWrapper": false,
    "XULDocument": false,
    "addLoadEvent": false,
    "add_task": false,
    "content": false,
    "executeSoon": false,
    "expectUncaughtException": false,
    "export_assertions": false,
    "extractJarToTmp": false,
    "finish": false,
    "gTestPath": false,
    "getChromeDir": false,
    "getJar": false,
    "getResolvedURI": false,
    "getRootDirectory": false,
    "getTestFilePath": false,
    "ignoreAllUncaughtExceptions": false,
    "info": false,
    "is": false,
    "isnot": false,
    "ok": false,
    "privateNoteIntentionalCrash": false,
    "registerCleanupFunction": false,
    "requestLongerTimeout": false,
    "todo": false,
    "todo_is": false,
    "todo_isnot": false,
    "waitForClipboard": false,
    "waitForExplicitFinish": false,
    "waitForFocus": false
  },

  "plugins": [
    "mozilla"
  ],

  "rules": {
    "mozilla/import-content-task-globals": "error",
    "mozilla/import-headjs-globals": "error",
    "mozilla/mark-test-function-used": "error",
    "mozilla/no-arbitrary-setTimeout": "error",
    "mozilla/no-cpows-in-tests": "error"
  }
};

==> thunderbird_66.0~b1.orig.tar.xz: thunderbird-66.0/tools/lint/eslint/eslint-plugin-mozilla/lib/configs/browser-test.js <==
// Parent config file for all browser-chrome files.
"use strict";

module.exports = {
  "env": {
    "browser": true,
    "mozilla/browser-window": true,
    "mozilla/simpletest": true,
    // "node": true
  },

  // All globals made available in the test environment.
  "globals": {
    // `$` is defined in SimpleTest.js
    "$": false,
    "Assert": false,
    "BrowserTestUtils": false,
    "ContentTask": false,
    "ContentTaskUtils": false,
    "EventUtils": false,
    "PromiseDebugging": false,
    "SpecialPowers": false,
    "TestUtils": false,
    "XPCNativeWrapper": false,
    "XULDocument": false,
    "addLoadEvent": false,
    "add_task": false,
    "content": false,
    "executeSoon": false,
    "expectUncaughtException": false,
    "export_assertions": false,
    "extractJarToTmp": false,
    "finish": false,
    "gTestPath": false,
    "getChromeDir": false,
    "getJar": false,
    "getResolvedURI": false,
    "getRootDirectory": false,
    "getTestFilePath": false,
    "ignoreAllUncaughtExceptions": false,
    "info": false,
    "is": false,
    "isnot": false,
    "ok": false,
    "privateNoteIntentionalCrash": false,
    "record": false,
    "registerCleanupFunction": false,
    "requestLongerTimeout": false,
    "setExpectedFailuresForSelfTest": false,
    "todo": false,
    "todo_is": false,
    "todo_isnot": false,
    "waitForClipboard": false,
    "waitForExplicitFinish": false,
    "waitForFocus": false,
  },

  "plugins": [
    "mozilla",
  ],

  "rules": {
    "mozilla/import-content-task-globals": "error",
    "mozilla/import-headjs-globals": "error",
    "mozilla/mark-test-function-used": "error",
    "mozilla/no-arbitrary-setTimeout": "error",
  },
};
